==> clickandpledge_connect-8.x-1.2002000101.tar.gz: clickandpledge_connect/src/Form/AddChannelGroup.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Uses to create pledgeTV channel forms.
 */
class AddChannelGroup extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_add_channel_group';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $displayForm = $this->displayChannelgroupsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Creates a form to store channel groups information.
   *
   * @param mixed $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayChannelgroupsForm($form, $form_state) {
    date_default_timezone_set(drupal_get_user_timezone());
    $form['cnpc_menu'] = [
      '#prefix' => '<div class="cnp_heading"><ul>
                        <li><a href="cnp_form_help">' . $this->t('Click & Pledge') . '</a></li>
                        <li><a href="cnp_form">' . $this->t('Form Groups') . '</a></li>
      <li><a class="cnpccurrent" href="CnPpledgeTVChannels">pledgeTV <sup class="cnpc-regsymbol">&reg;</sup></a></li>
                        <li><a href="cnp_formssettings">' . $this->t("Settings") . '</a></li>
                        </ul>',
      '#suffix' => '</div>',
    ];
    $form['cnpc_heading'] = [
      '#prefix' => '<div class="cnp_heading1">',
      '#suffix' => '</div>',
    ];
    $form['cnpc_channel_group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Channel Group Name*'),
      '#description' => $this->t('Please enter the channel group name<br><span class="cnpc_channelexists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_channel_group_name'],
    ];
    $data = $this->getAccountRecords();
    $options = [];
    foreach ($data as $rec) {
      $options[$rec->cnpstngs_AccountNumber . "||" . $rec->cnpstngs_guid . "||" . $rec->cnpstngs_ID] = $rec->cnpstngs_frndlyname . ' ( ' . $rec->cnpstngs_AccountNumber . ' )';
    }
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_action'] = [
      '#type' => 'hidden',
      '#default_value' => 'add',
      '#attributes' => ['id' => 'cnpc_action'],
    ];
    $form['cnpc_params_popup'] = [
      "#prefix" => '<div id="cnpc_myModal" class="cnpc-modal">
                <div class="cnpc-modal-content">
                  <div class="cnpc-modal-header">
                    <span class="cnpc-close">&times;</span>
                                                        <h2>' . $this->t('URL Parameter(s)') . '</h2>
                  </div>
                                                      <div class="cnpc-modal-body">',
    ];
    $form['cnpc_params_textarea'] = [
      '#prefix' => '<div class="cnpc-form-group">',
      '#type' => 'textarea',
      '#atrributes' => ['class' => ['paramsfeild']],
      '#suffix' => '</div>',
    ];
    $form['cnpc_params_textarea']['#theme_wrappers'] = [];
    $form['cnpc_params_buttons_start'] = [
      '#prefix' => '</div><div class="cnpc-modal-footer">',
    ];
    $form['cnpc_params_button_add'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ['class' => ['popupsavebtn'], 'id' => 'addparams'],
    ];
    $form['cnpc_params_button_close'] = [
      '#type' => 'button',
      '#value' => $this->t('close'),
      '#attributes' => ['class' => ['popupclosebtn'], 'id' => 'cnpc-close'],
    ];
    $form['cnpc_params_buttons_end'] = [
      '#suffix' => '</div></div></div>',
    ];
    $form['cnpc_accounts'] = [
      '#type' => 'select',
      '#title' => $this->t('Account(s)*'),
      '#options' => $options,
      '#attributes' => ['id' => 'cnpc_accounts'],
    ];
    $form['cnpc_start_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Start Date/Time* @dateC', ['@dateC' => '[TimeZone: ' . drupal_get_user_timezone() . ']']),
      '#attributes' => ['id' => 'start_date_time'],
      '#default_value' => date('F d, Y h:i a'),
    ];
    $form['cnpc_end_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('End Date/Time'),
      '#attributes' => ['id' => 'end_date_time'],
      '#default_value' => '',
    ];
    $form['cnpc_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('No Valid Channel Message'),
      '#attributes' => ['id' => 'cnpc_message'],
      '#default_value' => $this->t('Sorry! This channel is expired'),
    ];
    $form['cnpc_status'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => [
        'active' => $this->t('Active'),
        'inactive' => $this->t('Inactive'),
      ],
      '#attributes' => ['id' => 'cnpc_status'],
    ];
    $form['cnpcchnl_counter'] = [
      '#type' => 'hidden',
      '#attributes' => ['id' => 'cnpcchnl_counter'],
      '#default_value' => 0,
    ];
    // Hidden form Starts here, once click the save button it will display the
    // hidden form to add channels to channel group.
    $form['cnpc_settings_channel_start'] = [
      '#prefix' => '<div class="cnpc_settings_form" id="cnpc_settings_form"><ol><li>Select your Channel, enter a start date and click SAVE.</li><li>Copy the "shortcode" from pledgeTV<sup class="cnpc-regsymbol">&reg;</sup> Channels page, to your Drupal page. Multiple Channels may be added. Channels will display in order of start date. If start dates overlap, the first Channel in the list will show first.</li></ol>'
      . '<table id="custchnlrows"><tr>
                                                  <th>' . $this->t("Channel*") . '</th>
                                                  <th>' . $this->t("Start Date/Time*") . '</th>
                                                  <th>' . $this->t("End Date/Time") . '</th>
        <th>&nbsp;</th>
                                                  </tr><tbody id="dynachnlrows"></tbody></table><a href="#" id="addchannelrows">' . $this->t("Add Channel") . '</a>',
    ];
    $form['cnpc_settings_form_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_inital_buttons_start'] = [
      '#prefix' => '<div class="cnpc_inital_buttons">',
    ];
    $form['save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ['id' => 'chnlsavebtn'],
    ];
    $html1 = '<a id="resetbtn" href="cnppledgetvchannels" class="button button--reset js-form-submit form-submit">' . $this->t("Close") . '</a>';
    $form['gobackbtn_link_html1'] = [
      '#type' => 'markup',
      '#markup' => $html1,
    ];
    $form['cnpc_inital_buttons_end'] = [
      '#suffix' => '</div>',
    ];
    $form['cnpc_hide_buttons_start'] = [
      '#prefix' => '<div class="cnpc_hide_show_buttons">',
    ];
    $form['final_save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ['id' => 'finalchnlsave'],
    ];
    $html2 = '<a href="cnppledgetvchannels" class="button button--reset js-form-submit form-submit">' . $this->t("Close") . '</a>';
    $form['gobackbtn_link_html2'] = [
      '#type' => 'markup',
      '#markup' => $html2,
    ];
    $form['cnpc_hide_buttons_end'] = [
      '#suffix' => '</div>',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Form data is saving by using ajax calls.
  }

  /**
   * Get all the accounts and displayed on accounts drop down in the form.
   *
   * @return array
   *   Returns an array of account details.
   */
  public function getAccountRecords() {
    $prefix = $this->connection->tablePrefix();
    $table_name = $prefix . 'dp_cnpcsettingsdtl';
    $sql = "SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,cnpstngs_Date_Created,cnpstngs_Date_Modified FROM " . $table_name;
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

}

==> clickandpledge_connect-8.x-2.220700100.tar.gz: clickandpledge_connect/src/Form/AddChannelGroup.php <==
<?php

namespace Drupal\clickandpledge_connect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Connection;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;

/**
 * Uses to create pledgeTV channel forms.
 */
class AddChannelGroup extends FormBase {

  /**
   * The Connection.
   *
   * @var mixed
   */
  protected $connection;

  /**
   * The Constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cnpcaccount_add_channel_group';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#theme'] = 'cnp_add_channel_group';
    $displayForm = $this->displayChannelgroupsForm($form, $form_state);
    return $displayForm;
  }

  /**
   * Creates a form to store channel groups information.
   *
   * @param mixed $form
   *   An associative array containing the structure of the form.
   * @param mixed $form_state
   *   The current state of the form.
   *
   * @return array
   *   Returns The form structure.
   */
  public function displayChannelgroupsForm($form, $form_state) {
    date_default_timezone_set(date_default_timezone_get());
    $form['cnpc_channel_group_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Channel Group Name*'),
      '#description' => $this->t('Please enter the channel group name<br><span class="cnpc_channelexists_error"></span>'),
      '#default_value' => '',
      '#attributes' => ['id' => 'cnpc_channel_group_name'],
    ];
    $data = $this->getAccountRecords();
    $options = [];
    foreach ($data as $rec) {
      $options[$rec->cnpstngs_AccountNumber . "||" . $rec->cnpstngs_guid . "||" . $rec->cnpstngs_ID] = $rec->cnpstngs_frndlyname . ' ( ' . $rec->cnpstngs_AccountNumber . ' )';
    }
    $form['cnpc_channel_save_url'] = [
      '#type' => 'hidden',
      '#default_value' => Url::fromRoute('cnpconnect.cnpc_save_channel_data', [])->toString(),
      '#attributes' => ['id' => 'cnpc_channel_save_url'],
    ];
    $form['base_url_cnpc'] = [
      '#type' => 'hidden',
      '#default_value' => base_path(),
      '#attributes' => ['id' => 'base_url_cnpc'],
    ];
    $form['cnpc_action'] = [
      '#type' => 'hidden',
      '#default_value' => 'add',
      '#attributes' => ['id' => 'cnpc_action'],
    ];
    $form['cnpc_accounts'] = [
      '#type' => 'select',
      '#title' => $this->t('Account(s)*'),
      '#options' => $options,
      '#attributes' => ['id' => 'cnpc_accounts'],
    ];
    $form['cnpc_start_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Start Date/Time* @dateC', ['@dateC' => '[TimeZone: ' . date_default_timezone_get() . ']']),
      '#attributes' => ['id' => 'start_date_time'],
      '#default_value' => date('F d, Y h:i a'),
    ];
    $form['cnpc_end_date_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('End Date/Time'),
      '#attributes' => ['id' => 'end_date_time'],
      '#default_value' => '',
    ];
    $form['cnpc_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('No Valid Channel Message'),
      '#attributes' => ['id' => 'cnpc_message'],
      '#default_value' => $this->t('Sorry! This channel is expired'),
    ];
    $form['cnpc_status'] = [
      '#type' => 'select',
      '#title' => $this->t('Status'),
      '#options' => [
        'active' => $this->t('Active'),
        'inactive' => $this->t('Inactive'),
      ],
      '#attributes' => ['id' => 'cnpc_status'],
    ];
    $form['cnpcchnl_counter'] = [
      '#type' => 'hidden',
      '#attributes' => ['id' => 'cnpcchnl_counter'],
      '#default_value' => 0,
    ];
    // Hidden form Starts here, once click the save button it will display the
    // hidden form to add channels to channel group.
    $form['save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ['id' => 'chnlsavebtn'],
    ];
    $form['final_save'] = [
      '#type' => 'button',
      '#value' => $this->t('Save'),
      '#attributes' => ['id' => 'finalchnlsave'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Form data is saving by using ajax calls.
  }

  /**
   * Get all the accounts and displayed on accounts drop down in the form.
   *
   * @return array
   *   Returns an array of account details.
   */
  public function getAccountRecords() {
    $sql = 'SELECT cnpstngs_ID,cnpstngs_frndlyname,cnpstngs_AccountNumber,cnpstngs_guid,cnpstngs_status,cnpstngs_Date_Created,cnpstngs_Date_Modified FROM {dp_cnpcsettingsdtl}';
    $query = $this->connection->query($sql);
    return $query->fetchAll();
  }

}
